# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exome/v1/catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65xome/v1/catalog.proto\x12\x08\x65xome.v1\"2\n\x0fGetTokenRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"!\n\x10GetTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"M\n\x0fRunQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\nlibrary_id\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\"\'\n\x10RunQueryResponse\x12\x13\n\x0bipcResponse\x18\x01 \x01(\x0c\"P\n\x0cOrganization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\"1\n\x16GetOrganizationRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"G\n\x17GetOrganizationResponse\x12,\n\x0corganization\x18\x01 \x01(\x0b\x32\x16.exome.v1.Organization\",\n\x1bGetUserOrganizationsRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"M\n\x1cGetUserOrganizationsResponse\x12-\n\rorganizations\x18\x01 \x03(\x0b\x32\x16.exome.v1.Organization\"d\n\x04User\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\nupdated_at\x18\x05 \x01(\t\"I\n\x11\x43reateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\"#\n\x12\x43reateUserResponse\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"Z\n\x1d\x43reateUserAuthProviderRequest\x12\x14\n\x0c\x61uth_service\x18\x01 \x01(\t\x12\x0f\n\x07\x61uth_id\x18\x02 \x01(\t\x12\x12\n\nuser_email\x18\x03 \x01(\t\" \n\x1e\x43reateUserAuthProviderResponse\"\x1f\n\x0eGetUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"/\n\x0fGetUserResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.exome.v1.User\"&\n\x15GetUserByEmailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"6\n\x16GetUserByEmailResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.exome.v1.User\"\x18\n\x16ListFileFormatsRequest\"E\n\x17ListFileFormatsResponse\x12*\n\x0c\x66ile_formats\x18\x01 \x03(\x0b\x32\x14.exome.v1.FileFormat\"B\n\nFileFormat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\t\x12\x12\n\nupdated_at\x18\x03 \x01(\t\"`\n\x07Library\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\nupdated_at\x18\x05 \x01(\t\"R\n\x14\x43reateLibraryRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\"#\n\x15\x43reateLibraryResponse\x12\n\n\x02id\x18\x01 \x01(\t\"/\n\x14ListLibrariesRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"=\n\x15ListLibrariesResponse\x12$\n\tlibraries\x18\x01 \x03(\x0b\x32\x11.exome.v1.Library\"\x1f\n\x11GetLibraryRequest\x12\n\n\x02id\x18\x01 \x01(\t\"8\n\x12GetLibraryResponse\x12\"\n\x07library\x18\x01 \x01(\x0b\x32\x11.exome.v1.Library\"@\n\x17GetLibraryByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\">\n\x18GetLibraryByNameResponse\x12\"\n\x07library\x18\x01 \x01(\x0b\x32\x11.exome.v1.Library\"_\n\x07\x43\x61talog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nlibrary_id\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\nupdated_at\x18\x05 \x01(\t\"8\n\x14\x43reateCatalogRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nlibrary_id\x18\x02 \x01(\t\"#\n\x15\x43reateCatalogResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x1f\n\x11GetCatalogRequest\x12\n\n\x02id\x18\x01 \x01(\t\"8\n\x12GetCatalogResponse\x12\"\n\x07\x63\x61talog\x18\x01 \x01(\x0b\x32\x11.exome.v1.Catalog\")\n\x13ListCatalogsRequest\x12\x12\n\nlibrary_id\x18\x01 \x01(\t\";\n\x14ListCatalogsResponse\x12#\n\x08\x63\x61talogs\x18\x01 \x03(\x0b\x32\x11.exome.v1.Catalog\";\n\x17GetCatalogByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nlibrary_id\x18\x02 \x01(\t\">\n\x18GetCatalogByNameResponse\x12\"\n\x07\x63\x61talog\x18\x01 \x01(\x0b\x32\x11.exome.v1.Catalog\"\xa8\x01\n\x06Schema\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tauthority\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x12\n\nis_listing\x18\x06 \x01(\x08\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\x12\x12\n\ncatalog_id\x18\t \x01(\t\"\x81\x01\n\x13\x43reateSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tauthority\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x12\n\nis_listing\x18\x05 \x01(\x08\x12\x12\n\ncatalog_id\x18\x06 \x01(\t\"\"\n\x14\x43reateSchemaResponse\x12\n\n\x02id\x18\x01 \x01(\t\"(\n\x12ListSchemasRequest\x12\x12\n\ncatalog_id\x18\x01 \x01(\t\"8\n\x13ListSchemasResponse\x12!\n\x07schemas\x18\x01 \x03(\x0b\x32\x10.exome.v1.Schema\"\x1e\n\x10GetSchemaRequest\x12\n\n\x02id\x18\x01 \x01(\t\"5\n\x11GetSchemaResponse\x12 \n\x06schema\x18\x01 \x01(\x0b\x32\x10.exome.v1.Schema\":\n\x16GetSchemaByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\";\n\x17GetSchemaByNameResponse\x12 \n\x06schema\x18\x01 \x01(\x0b\x32\x10.exome.v1.Schema\"\xc9\x01\n\x05Table\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x11\n\tschema_id\x18\x05 \x01(\t\x12\x13\n\x0b\x66ile_format\x18\x06 \x01(\t\x12\x12\n\nis_listing\x18\x07 \x01(\x08\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\x12\x1b\n\x13\x63ompression_type_id\x18\n \x01(\t\"\x85\x01\n\x12\x43reateTableRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x11\n\tschema_id\x18\x04 \x01(\t\x12\x13\n\x0b\x66ile_format\x18\x05 \x01(\t\x12\x12\n\nis_listing\x18\x06 \x01(\x08\"!\n\x13\x43reateTableResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x1d\n\x0fGetTableRequest\x12\n\n\x02id\x18\x01 \x01(\t\"2\n\x10GetTableResponse\x12\x1e\n\x05table\x18\x01 \x01(\x0b\x32\x0f.exome.v1.Table\"&\n\x11ListTablesRequest\x12\x11\n\tschema_id\x18\x01 \x01(\t\"5\n\x12ListTablesResponse\x12\x1f\n\x06tables\x18\x01 \x03(\x0b\x32\x0f.exome.v1.Table\"8\n\x15GetTableByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tschema_id\x18\x02 \x01(\t\"8\n\x16GetTableByNameResponse\x12\x1e\n\x05table\x18\x01 \x01(\x0b\x32\x0f.exome.v1.Table\"\xbe\x01\n\x0cUserAuditLog\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\x12\x1a\n\x12target_entity_type\x18\x06 \x01(\t\x12\x18\n\x10target_entity_id\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\"1\n\x16GetUserAuditLogRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"?\n\x17GetUserAuditLogResponse\x12$\n\x04logs\x18\x01 \x03(\x0b\x32\x16.exome.v1.UserAuditLog2\xf7\x10\n\x0e\x43\x61talogService\x12R\n\rCreateLibrary\x12\x1e.exome.v1.CreateLibraryRequest\x1a\x1f.exome.v1.CreateLibraryResponse\"\x00\x12R\n\rListLibraries\x12\x1e.exome.v1.ListLibrariesRequest\x1a\x1f.exome.v1.ListLibrariesResponse\"\x00\x12I\n\nGetLibrary\x12\x1b.exome.v1.GetLibraryRequest\x1a\x1c.exome.v1.GetLibraryResponse\"\x00\x12[\n\x10GetLibraryByName\x12!.exome.v1.GetLibraryByNameRequest\x1a\".exome.v1.GetLibraryByNameResponse\"\x00\x12R\n\rCreateCatalog\x12\x1e.exome.v1.CreateCatalogRequest\x1a\x1f.exome.v1.CreateCatalogResponse\"\x00\x12I\n\nGetCatalog\x12\x1b.exome.v1.GetCatalogRequest\x1a\x1c.exome.v1.GetCatalogResponse\"\x00\x12O\n\x0cListCatalogs\x12\x1d.exome.v1.ListCatalogsRequest\x1a\x1e.exome.v1.ListCatalogsResponse\"\x00\x12[\n\x10GetCatalogByName\x12!.exome.v1.GetCatalogByNameRequest\x1a\".exome.v1.GetCatalogByNameResponse\"\x00\x12O\n\x0c\x43reateSchema\x12\x1d.exome.v1.CreateSchemaRequest\x1a\x1e.exome.v1.CreateSchemaResponse\"\x00\x12L\n\x0bListSchemas\x12\x1c.exome.v1.ListSchemasRequest\x1a\x1d.exome.v1.ListSchemasResponse\"\x00\x12\x46\n\tGetSchema\x12\x1a.exome.v1.GetSchemaRequest\x1a\x1b.exome.v1.GetSchemaResponse\"\x00\x12X\n\x0fGetSchemaByName\x12 .exome.v1.GetSchemaByNameRequest\x1a!.exome.v1.GetSchemaByNameResponse\"\x00\x12L\n\x0b\x43reateTable\x12\x1c.exome.v1.CreateTableRequest\x1a\x1d.exome.v1.CreateTableResponse\"\x00\x12I\n\nListTables\x12\x1b.exome.v1.ListTablesRequest\x1a\x1c.exome.v1.ListTablesResponse\"\x00\x12\x43\n\x08GetTable\x12\x19.exome.v1.GetTableRequest\x1a\x1a.exome.v1.GetTableResponse\"\x00\x12U\n\x0eGetTableByName\x12\x1f.exome.v1.GetTableByNameRequest\x1a .exome.v1.GetTableByNameResponse\"\x00\x12X\n\x0fListFileFormats\x12 .exome.v1.ListFileFormatsRequest\x1a!.exome.v1.ListFileFormatsResponse\"\x00\x12I\n\nCreateUser\x12\x1b.exome.v1.CreateUserRequest\x1a\x1c.exome.v1.CreateUserResponse\"\x00\x12m\n\x16\x43reateUserAuthProvider\x12\'.exome.v1.CreateUserAuthProviderRequest\x1a(.exome.v1.CreateUserAuthProviderResponse\"\x00\x12\x43\n\x08GetToken\x12\x19.exome.v1.GetTokenRequest\x1a\x1a.exome.v1.GetTokenResponse\"\x00\x12@\n\x07GetUser\x12\x18.exome.v1.GetUserRequest\x1a\x19.exome.v1.GetUserResponse\"\x00\x12U\n\x0eGetUserByEmail\x12\x1f.exome.v1.GetUserByEmailRequest\x1a .exome.v1.GetUserByEmailResponse\"\x00\x12g\n\x14GetUserOrganizations\x12%.exome.v1.GetUserOrganizationsRequest\x1a&.exome.v1.GetUserOrganizationsResponse\"\x00\x12X\n\x0fGetOrganization\x12 .exome.v1.GetOrganizationRequest\x1a!.exome.v1.GetOrganizationResponse\"\x00\x12X\n\x0fGetUserAuditLog\x12 .exome.v1.GetUserAuditLogRequest\x1a!.exome.v1.GetUserAuditLogResponse\"\x00\x12\x43\n\x08RunQuery\x12\x19.exome.v1.RunQueryRequest\x1a\x1a.exome.v1.RunQueryResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exome.v1.catalog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETTOKENREQUEST']._serialized_start=36
  _globals['_GETTOKENREQUEST']._serialized_end=86
  _globals['_GETTOKENRESPONSE']._serialized_start=88
  _globals['_GETTOKENRESPONSE']._serialized_end=121
  _globals['_RUNQUERYREQUEST']._serialized_start=123
  _globals['_RUNQUERYREQUEST']._serialized_end=200
  _globals['_RUNQUERYRESPONSE']._serialized_start=202
  _globals['_RUNQUERYRESPONSE']._serialized_end=241
  _globals['_ORGANIZATION']._serialized_start=243
  _globals['_ORGANIZATION']._serialized_end=323
  _globals['_GETORGANIZATIONREQUEST']._serialized_start=325
  _globals['_GETORGANIZATIONREQUEST']._serialized_end=374
  _globals['_GETORGANIZATIONRESPONSE']._serialized_start=376
  _globals['_GETORGANIZATIONRESPONSE']._serialized_end=447
  _globals['_GETUSERORGANIZATIONSREQUEST']._serialized_start=449
  _globals['_GETUSERORGANIZATIONSREQUEST']._serialized_end=493
  _globals['_GETUSERORGANIZATIONSRESPONSE']._serialized_start=495
  _globals['_GETUSERORGANIZATIONSRESPONSE']._serialized_end=572
  _globals['_USER']._serialized_start=574
  _globals['_USER']._serialized_end=674
  _globals['_CREATEUSERREQUEST']._serialized_start=676
  _globals['_CREATEUSERREQUEST']._serialized_end=749
  _globals['_CREATEUSERRESPONSE']._serialized_start=751
  _globals['_CREATEUSERRESPONSE']._serialized_end=786
  _globals['_CREATEUSERAUTHPROVIDERREQUEST']._serialized_start=788
  _globals['_CREATEUSERAUTHPROVIDERREQUEST']._serialized_end=878
  _globals['_CREATEUSERAUTHPROVIDERRESPONSE']._serialized_start=880
  _globals['_CREATEUSERAUTHPROVIDERRESPONSE']._serialized_end=912
  _globals['_GETUSERREQUEST']._serialized_start=914
  _globals['_GETUSERREQUEST']._serialized_end=945
  _globals['_GETUSERRESPONSE']._serialized_start=947
  _globals['_GETUSERRESPONSE']._serialized_end=994
  _globals['_GETUSERBYEMAILREQUEST']._serialized_start=996
  _globals['_GETUSERBYEMAILREQUEST']._serialized_end=1034
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_start=1036
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_end=1090
  _globals['_LISTFILEFORMATSREQUEST']._serialized_start=1092
  _globals['_LISTFILEFORMATSREQUEST']._serialized_end=1116
  _globals['_LISTFILEFORMATSRESPONSE']._serialized_start=1118
  _globals['_LISTFILEFORMATSRESPONSE']._serialized_end=1187
  _globals['_FILEFORMAT']._serialized_start=1189
  _globals['_FILEFORMAT']._serialized_end=1255
  _globals['_LIBRARY']._serialized_start=1257
  _globals['_LIBRARY']._serialized_end=1353
  _globals['_CREATELIBRARYREQUEST']._serialized_start=1355
  _globals['_CREATELIBRARYREQUEST']._serialized_end=1437
  _globals['_CREATELIBRARYRESPONSE']._serialized_start=1439
  _globals['_CREATELIBRARYRESPONSE']._serialized_end=1474
  _globals['_LISTLIBRARIESREQUEST']._serialized_start=1476
  _globals['_LISTLIBRARIESREQUEST']._serialized_end=1523
  _globals['_LISTLIBRARIESRESPONSE']._serialized_start=1525
  _globals['_LISTLIBRARIESRESPONSE']._serialized_end=1586
  _globals['_GETLIBRARYREQUEST']._serialized_start=1588
  _globals['_GETLIBRARYREQUEST']._serialized_end=1619
  _globals['_GETLIBRARYRESPONSE']._serialized_start=1621
  _globals['_GETLIBRARYRESPONSE']._serialized_end=1677
  _globals['_GETLIBRARYBYNAMEREQUEST']._serialized_start=1679
  _globals['_GETLIBRARYBYNAMEREQUEST']._serialized_end=1743
  _globals['_GETLIBRARYBYNAMERESPONSE']._serialized_start=1745
  _globals['_GETLIBRARYBYNAMERESPONSE']._serialized_end=1807
  _globals['_CATALOG']._serialized_start=1809
  _globals['_CATALOG']._serialized_end=1904
  _globals['_CREATECATALOGREQUEST']._serialized_start=1906
  _globals['_CREATECATALOGREQUEST']._serialized_end=1962
  _globals['_CREATECATALOGRESPONSE']._serialized_start=1964
  _globals['_CREATECATALOGRESPONSE']._serialized_end=1999
  _globals['_GETCATALOGREQUEST']._serialized_start=2001
  _globals['_GETCATALOGREQUEST']._serialized_end=2032
  _globals['_GETCATALOGRESPONSE']._serialized_start=2034
  _globals['_GETCATALOGRESPONSE']._serialized_end=2090
  _globals['_LISTCATALOGSREQUEST']._serialized_start=2092
  _globals['_LISTCATALOGSREQUEST']._serialized_end=2133
  _globals['_LISTCATALOGSRESPONSE']._serialized_start=2135
  _globals['_LISTCATALOGSRESPONSE']._serialized_end=2194
  _globals['_GETCATALOGBYNAMEREQUEST']._serialized_start=2196
  _globals['_GETCATALOGBYNAMEREQUEST']._serialized_end=2255
  _globals['_GETCATALOGBYNAMERESPONSE']._serialized_start=2257
  _globals['_GETCATALOGBYNAMERESPONSE']._serialized_end=2319
  _globals['_SCHEMA']._serialized_start=2322
  _globals['_SCHEMA']._serialized_end=2490
  _globals['_CREATESCHEMAREQUEST']._serialized_start=2493
  _globals['_CREATESCHEMAREQUEST']._serialized_end=2622
  _globals['_CREATESCHEMARESPONSE']._serialized_start=2624
  _globals['_CREATESCHEMARESPONSE']._serialized_end=2658
  _globals['_LISTSCHEMASREQUEST']._serialized_start=2660
  _globals['_LISTSCHEMASREQUEST']._serialized_end=2700
  _globals['_LISTSCHEMASRESPONSE']._serialized_start=2702
  _globals['_LISTSCHEMASRESPONSE']._serialized_end=2758
  _globals['_GETSCHEMAREQUEST']._serialized_start=2760
  _globals['_GETSCHEMAREQUEST']._serialized_end=2790
  _globals['_GETSCHEMARESPONSE']._serialized_start=2792
  _globals['_GETSCHEMARESPONSE']._serialized_end=2845
  _globals['_GETSCHEMABYNAMEREQUEST']._serialized_start=2847
  _globals['_GETSCHEMABYNAMEREQUEST']._serialized_end=2905
  _globals['_GETSCHEMABYNAMERESPONSE']._serialized_start=2907
  _globals['_GETSCHEMABYNAMERESPONSE']._serialized_end=2966
  _globals['_TABLE']._serialized_start=2969
  _globals['_TABLE']._serialized_end=3170
  _globals['_CREATETABLEREQUEST']._serialized_start=3173
  _globals['_CREATETABLEREQUEST']._serialized_end=3306
  _globals['_CREATETABLERESPONSE']._serialized_start=3308
  _globals['_CREATETABLERESPONSE']._serialized_end=3341
  _globals['_GETTABLEREQUEST']._serialized_start=3343
  _globals['_GETTABLEREQUEST']._serialized_end=3372
  _globals['_GETTABLERESPONSE']._serialized_start=3374
  _globals['_GETTABLERESPONSE']._serialized_end=3424
  _globals['_LISTTABLESREQUEST']._serialized_start=3426
  _globals['_LISTTABLESREQUEST']._serialized_end=3464
  _globals['_LISTTABLESRESPONSE']._serialized_start=3466
  _globals['_LISTTABLESRESPONSE']._serialized_end=3519
  _globals['_GETTABLEBYNAMEREQUEST']._serialized_start=3521
  _globals['_GETTABLEBYNAMEREQUEST']._serialized_end=3577
  _globals['_GETTABLEBYNAMERESPONSE']._serialized_start=3579
  _globals['_GETTABLEBYNAMERESPONSE']._serialized_end=3635
  _globals['_USERAUDITLOG']._serialized_start=3638
  _globals['_USERAUDITLOG']._serialized_end=3828
  _globals['_GETUSERAUDITLOGREQUEST']._serialized_start=3830
  _globals['_GETUSERAUDITLOGREQUEST']._serialized_end=3879
  _globals['_GETUSERAUDITLOGRESPONSE']._serialized_start=3881
  _globals['_GETUSERAUDITLOGRESPONSE']._serialized_end=3944
  _globals['_CATALOGSERVICE']._serialized_start=3947
  _globals['_CATALOGSERVICE']._serialized_end=6114
# @@protoc_insertion_point(module_scope)
